==> oshi-core-5.2.5-sources.jar: oshi/PlatformEnum.java <==
/**
 * MIT License
 *
 * Copyright (c) 2010 - 2020 The OSHI Project Contributors: https://github.com/oshi/oshi/graphs/contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package oshi;

/**
 * Enum of supported operating systems.
 */
public enum PlatformEnum {
    /**
     * Microsoft Windows
     */
    WINDOWS,
    /**
     * A flavor of Linux
     */
    LINUX,
    /**
     * macOS (formerly OS X)
     */
    MACOSX,
    /**
     * Solaris (SunOS)
     */
    SOLARIS,
    /**
     * FreeBSD
     */
    FREEBSD,
    /**
     * IBM AIX
     */
    AIX,
    /**
     * OpenBSD, WindowsCE, or an unspecified system
     */
    UNKNOWN;
}

==> oshi-core-5.5.0-sources.jar: oshi/PlatformEnum.java <==
/**
 * MIT License
 *
 * Copyright (c) 2010 - 2021 The OSHI Project Contributors: https://github.com/oshi/oshi/graphs/contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package oshi;

/**
 * Enum of supported operating systems.
 */
public enum PlatformEnum {
    /**
     * Microsoft Windows
     */
    WINDOWS,
    /**
     * A flavor of Linux
     */
    LINUX,
    /**
     * macOS (formerly OS X)
     */
    MACOS,
    /**
     * Mac OS X
     *
     * @deprecated Use {@link #MACOS}
     */
    @Deprecated
    MACOSX,
    /**
     * Solaris (SunOS)
     */
    SOLARIS,
    /**
     * FreeBSD
     */
    FREEBSD,
    /**
     * IBM AIX
     */
    AIX,
    /**
     * OpenBSD
     */
    OPENBSD,
    /**
     * WindowsCE, or an unspecified system
     */
    UNKNOWN;
}
